# Mozilla User Preferences

/* Do not edit this file.
 *
 * If you make changes to this file while the application is running,
 * the changes will be overwritten when the application exits.
 *
 * To make a manual change to preferences, you can visit the URL about:config
 */

user_pref("extensions.sieve.account.bla%40kde.org@sever.foo.org.TLS", true);
user_pref("extensions.sieve.account.bla%40kde.org@sever.foo.org.TLS.forced", true);
user_pref("extensions.sieve.account.bla%40kde.org@sever.foo.org.activeAuthorization", 1);
user_pref("extensions.sieve.account.bla%40kde.org@sever.foo.org.activeHost", 0);
user_pref("extensions.sieve.account.bla%40kde.org@sever.foo.org.activeLogin", 1);
user_pref("extensions.sieve.account.bla%40kde.org@sever.foo.org.enabled", true);
user_pref("extensions.sieve.account.bla%40kde.org@sever.foo.org.port.type", 0);
user_pref("extensions.sieve.account.bla%40kde.org@sever.foo.org.proxy.type", 1);
user_pref("extensions.sieve.account.bli%40kde.org@sever.foo.org.enabled", true);
user_pref("mail.account.account1.identities", "id1");
user_pref("mail.account.account1.server", "server1");
user_pref("mail.account.account2.server", "server2");
user_pref("mail.account.account3.identities", "id2");
user_pref("mail.account.account3.server", "server3");
user_pref("mail.account.lastKey", 3);
user_pref("mail.accountmanager.accounts", "account1,account2,account3");
user_pref("mail.accountmanager.defaultaccount", "account1");
user_pref("mail.accountmanager.localfoldersserver", "server2");
user_pref("mail.server.server1.ageLimit", 30);
user_pref("mail.server.server1.applyToFlaggedMessages", false);
user_pref("mail.server.server1.cacheCapa.acl", false);
user_pref("mail.server.server1.cacheCapa.quota", false);
user_pref("mail.server.server1.check_new_mail", true);
user_pref("mail.server.server1.cleanupBodies", false);
user_pref("mail.server.server1.daysToKeepBodies", 30);
user_pref("mail.server.server1.daysToKeepHdrs", 30);
user_pref("mail.server.server1.directory", "/home/bla/.thunderbird/55.default/ImapMail/sever.foo.org");
user_pref("mail.server.server1.directory-rel", "[ProfD]ImapMail/sever.foo.org");
user_pref("mail.server.server1.downloadByDate", false);
user_pref("mail.server.server1.downloadUnreadOnly", false);
user_pref("mail.server.server1.hostname", "sever.foo.org");
user_pref("mail.server.server1.keepUnreadOnly", false);
user_pref("mail.server.server1.login_at_startup", true);
user_pref("mail.server.server1.max_cached_connections", 5);
user_pref("mail.server.server1.name", "bla@kde.org");
user_pref("mail.server.server1.namespace.personal", "\"INBOX.\"");
user_pref("mail.server.server1.numHdrsToKeep", 2000);
user_pref("mail.server.server1.port", 993);
user_pref("mail.server.server1.socketType", 0);
user_pref("mail.server.server1.timeout", 29);
user_pref("mail.server.server1.type", "imap");
user_pref("mail.server.server1.userName", "bla@kde.org");
user_pref("mail.server.server2.ageLimit", 30);
user_pref("mail.server.server2.applyToFlaggedMessages", false);
user_pref("mail.server.server2.cleanupBodies", false);
user_pref("mail.server.server2.daysToKeepBodies", 30);
user_pref("mail.server.server2.daysToKeepHdrs", 30);
user_pref("mail.server.server2.directory", "/home/bla/.thunderbird/55.default/Mail/Local Folders");
user_pref("mail.server.server2.directory-rel", "[ProfD]Mail/Local Folders");
user_pref("mail.server.server2.downloadByDate", false);
user_pref("mail.server.server2.downloadUnreadOnly", false);
user_pref("mail.server.server2.hostname", "Local Folders");
user_pref("mail.server.server2.keepUnreadOnly", false);
user_pref("mail.server.server2.name", "Dossiers locaux");
user_pref("mail.server.server2.numHdrsToKeep", 2000);
user_pref("mail.server.server2.spamActionTargetAccount", "mailbox://nobody@Local%20Folders");
user_pref("mail.server.server2.storeContractID", "@mozilla.org/msgstore/berkeleystore;1");
user_pref("mail.server.server2.type", "none");
user_pref("mail.server.server2.userName", "nobody");
user_pref("mail.server.server3.canChangeStoreType", true);
user_pref("mail.server.server3.check_new_mail", true);
user_pref("mail.server.server3.directory", "/home/bla/.thunderbird/55.default/ImapMail/dd.kde.org");
user_pref("mail.server.server3.directory-rel", "[ProfD]ImapMail/dd.kde.org");
user_pref("mail.server.server3.hostname", "sever.foo.org");
user_pref("mail.server.server3.login_at_startup", true);
user_pref("mail.server.server3.max_cached_connections", 5);
user_pref("mail.server.server3.name", "gre@kde.org");
user_pref("mail.server.server3.port", 993);
user_pref("mail.server.server3.socketType", 0);
user_pref("mail.server.server3.spamActionTargetAccount", "imap://bli@kde.org@sever.foo.org");
user_pref("mail.server.server3.type", "imap");
user_pref("mail.server.server3.userName", "bli@kde.org");
