<!DOCTYPE gui SYSTEM "kpartgui.dtd">
<!--
  SPDX-License-Identifier: CC0-1.0
  SPDX-FileCopyrightText: 2013-2026 Laurent Montel <montel@kde.org>
-->
<gui name="sieveeditor" version="26">
 <MenuBar>
  <Menu name="file" >
   <Action name="add_server_sieve" />
   <Separator/>
   <Action name="create_new_script" />
   <Separator/>
   <Action name="share_script"/>
   <Separator/>
   <Action name="import_script"/>
   <Separator/>
   <Action name="delete_script" />
   <Separator/>
   <Action name="refresh_list"/>
   <Separator/>
  </Menu>
  <Menu name="edit" >
   <text>&amp;Edit</text>
   <Action name="check_spelling" />
   <Separator/>
   <Action name="gotoline" />
   <Separator/>
   <Action name="wordwrap" />
   <Separator/>
   <Action name="comment_code" />
   <Action name="uncomment_code" />
   <Separator/>
   <Action name="change_case_menu" />
  </Menu>
  <Menu name="view" >
   <text>View</text>
   <Action name="zoom_in" />
   <Action name="zoom_out" />
   <Separator/>
   <Action name="zoom_reset" />
   <Separator/>
   <Action name="fullscreen"/>
  </Menu>
  <Menu name="settings" append="settings_merge">
    <text>&amp;Settings</text>
    <Action name="colorscheme_menu" />
  </Menu>
  <Action name="bookmark"/>
  <Menu name="Tools" >
   <text>Tools</text>
   <Action name="check_syntax" />
   <Separator/>
   <Action name="autogenerate_script" />
   <Separator/>
   <Action name="debug_sieve" />
   <Separator/>
   <Action name="import_imap_settings" />
  </Menu>

  <Menu name="help">
   <text>&amp;Help</text>
   <Action name="verify_check_version" />
   <Separator/>
   <Action name="whatsnew" />
   <Separator/>
  </Menu>

 </MenuBar>

  <ToolBar name="mainToolBar"><text>Main Toolbar</text>
<Spacer/>
    <Action name="hamburger_menu"/>
  </ToolBar>

</gui>
